@@ -28,7 +28,7 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '1.5'
+__version__ = '1.5.1'
 
 
 IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp',)
@@ -289,7 +289,7 @@ class FileStorage(object):
         content_type = OPENXML_MIMETYPES.get(ext, filesto.content_type)
 
         data = {
-            'path': filepath,
+            'path': os.path.join(filepath, filename),
             'size': filesize,
             'content_type': content_type,
         }
@@ -332,17 +332,18 @@ class File(object):
 
     def __init__(self, data):
         data = data or {}
+
+        # Backwards compatibility
         path = data.get('path', u'').strip('/')
         if not path:
-            path = u'/%s/%s' % (
+            path = u'%s/%s' % (
                 data.get('relpath', u''), data.get('name', u''))
-        else:
-            path = u'/' + path
 
         self.path = path
         self.size = data.get('size', u'')
         self.content_type = data.get('content_type', u'')
-        self.url = data.get('url') or path
+
+        self.url = data.get('url')
         self.width = data.get('width')
         self.height = data.get('height')
 
@@ -352,7 +353,7 @@ class File(object):
 
     @property
     def relpath(self):
-        return os.path.basedir(self.path)
+        return self.path
 
     @property
     def is_image(self):
@@ -368,12 +369,6 @@ class File(object):
     def __repr__(self):
         return repr(self.to_dict())
 
-    def remove(self):
-        try:
-            os.remove(self.path)
-        except OSError:
-            pass
-
     def to_dict(self):
         """Serialize to a dictionary.
         """
@@ -381,8 +376,9 @@ class File(object):
             'path': self.path,
             'size': self.size,
             'content_type': self.content_type,
-            'url': self.url,
         }
+        if self.url:
+            data['url'] = self.url
         if self.width:
             data['width'] = self.width
         if self.height:
@@ -397,7 +393,6 @@ class File(object):
 
 if sqlalchemy_available:
     class FileType(TypeDecorator):
-
         """Saves a File as a JSON-encoded string and reads it back as
         a File."""
 
@@ -426,3 +421,4 @@ if sqlalchemy_available:
 
         def copy(self):
             return self.__class__(default=self.default, **self.kwargs)
+
