@@ -33,13 +33,13 @@ def format_path(tmplpath, filename, now=None):
     {a+}: Filename first letters
     {z+}: Filename last letters
     {r+}: Random letters and/or numbers
-    
+
         >>> tmplpath = '{zzz}/{yyyy}/{a}/{a}/{a}'
         >>> filename = 'monkey.png'
         >>> now = datetime(2010, 1, 14)
         >>> format_path(tmplpath, filename, now)
         'png/2010/m/o/n/'
-    
+
     """
     path = tmplpath.lower()
     filename = filename.lower()
@@ -88,8 +88,8 @@ def format_path(tmplpath, filename, now=None):
             z_pos = new_z_pos
         elif pattern.startswith('r'):
             allowed_chars = 'abcdefghijklmnopqrstuvwxyz1234567890'
-            replace = ''.join([random.choice(allowed_chars) \
-                for i in range(len_pattern)])
+            replace = ''.join([random.choice(allowed_chars)
+                              for i in range(len_pattern)])
         else:
             raise ValueError
         x, y = match.span()
@@ -115,7 +115,6 @@ def get_unique_filename(root_path, path, name, ext=''):
             filename = secure_filename(filename)
         else:
             filename = secure_filename(name)
-        
         if ext:
             filename = '%s.%s' % (filename, ext.strip('.'))
         filepath = os.path.join(abspath, filename)
@@ -130,7 +129,7 @@ def make_dirs(root_path, filepath):
     fullpath = os.path.abspath(fullpath)
     try:
         os.makedirs(fullpath)
-    except (OSError), e:
+    except OSError as e:
         if e.errno != errno.EEXIST:
             raise
     return fullpath
